@@ -120,13 +120,17 @@ class ConfigurationBase():
         config = {**old_config, **config}
         return config
 
+    def _retain_only_updated_options(self):
+        parser = self.get_parser('update')
+        for action in parser._actions:
+            if (len(action.option_strings) > 0) and (action.default != '==SUPPRESS=='):
+                action.default=None
+        args = parser.parse_args(sys.argv[3:])
+        return args
+
     def configure(self, args, action='create'):
         if action == 'update':
-            parser = self.get_parser(action)
-            for action in parser._actions:
-                if (len(action.option_strings) > 0) and (action.default != '==SUPPRESS=='):
-                    action.default=None
-            args = parser.parse_args(sys.argv[3:])
+            args = self._retain_only_updated_options()
 
         config = vars(args)
         
