@@ -107,7 +107,8 @@ class JobHandler():
             module = importlib.import_module(script_name_noext)
             model = getattr(module, model_name)
         except: 
-            raise ImportError('Unable to import {} from training script: {}.py'.format(model_name, script_name))
+            raise ImportError('Unable to import function/class {} '
+                'from training script: {}.py'.format(model_name, script_name_noext))
         return model
 
     def save_metadata(self, df, summary={}):
